@@ -805,22 +805,20 @@ while (time < $s) {
     print_it($F, 'Testing XOR Drawing Mode');
 
     $F->xor_mode();
-    my $size = int(($YY - $F->{'Y_CLIP'}) / 3);
-    my $mid  = int($XX / 2);
 
-    $F->set_color({'red' => 255, 'green' => 255, 'blue' => 0});
-    $F->circle({'x' => $mid - ($size / 2),'y'=> $F->{'Y_CLIP'} + $size*2,'radius' => $size, 'filled' => 1});
     $F->set_color({'red' => 0, 'green' => 255, 'blue' => 255});
-    $F->circle({'x' => $mid,'y'=> $F->{'Y_CLIP'} + $size,'radius' => $size, 'filled' => 1});
+    $F->rbox({'x' => 0,'y' => 0, 'width'=> ($XX / 2),'height' => ($YY / 2),'filled' => 1});
     $F->set_color({'red' => 255, 'green' => 0, 'blue' => 255});
-    $F->circle({'x' => $mid + ($size / 2),'y'=> $F->{'Y_CLIP'} + $size * 2,'radius' => $size, 'filled' => 1});
+    $F->rbox({'x' => $XX / 4,'y' => $YY / 4, 'width'=> ($XX / 2),'height' => ($YY / 2),'filled' => 1});
+    $F->set_color({'red' => 255, 'green' => 255, 'blue' => 0});
+    $F->rbox({'x' => ($XX / 2),'y' => ($YY / 2), 'width'=> ($XX / 2),'height' => ($YY / 2),'filled' => 1});
     sleep $factor;
 }
 
 {
     print_it($F, 'Testing AND Drawing Mode');
 
-    $F->set_color({'red' => 100, 'green' => 100, 'blue' => 100});
+    $F->set_color({'red' => 255, 'green' => 255, 'blue' => 255});
     $F->box({'x' => 0, 'y' => $F->{'Y_CLIP'}, 'xx' => $XX,'yy' => $YY, 'filled' => 1});
     $F->and_mode();
     my $size = int(($YY - $F->{'Y_CLIP'}) / 3);
@@ -842,18 +840,18 @@ while (time < $s) {
         {
             'x'      => 0,
             'y'      => $F->{'Y_CLIP'},
-            'width'  => $XX,
-            'height' => $h,
+            'width'  => $XX/2,
+            'height' => $h/2,
             'file'   => 'images/GFB.png',
-            'center' => 1
+            'center' => 3
         }
     );
     my $image2 = $F->load_image(
         {
             'x'      => 0,
             'y'      => $F->{'Y_CLIP'},
-            'width'  => $XX,
-            'height' => $h,
+            'width'  => $XX/2,
+            'height' => $h/2,
             'file'   => 'images/RWBY_beuowolf.jpg',
             'center' => 3,
             'convertalpha' => 1
@@ -864,19 +862,21 @@ while (time < $s) {
     $F->blit_write($image2);
     sleep $factor;
 
-    print_it($F,'Simulating MASK Mode with the much quicker "blit_transform" and "merge"');
-    $F->blit_write($image1);
-    $F->blit_write(
-        $F->blit_transform(
-            {
-                'blit_data' => $image2,
-                'merge'     => {
-                    'dest_blit_data'=> $F->blit_read($image2)
+    if ($F->{'BITS'} > 16) {
+        print_it($F,'Simulating MASK Mode with the much quicker "blit_transform" and "merge"');
+        $F->blit_write($image1);
+        $F->blit_write(
+            $F->blit_transform(
+                {
+                    'blit_data' => $image2,
+                    'merge'     => {
+                        'dest_blit_data'=> $F->blit_read($image2)
+                    }
                 }
-            }
-        )
-    );
-    sleep $factor;
+            )
+        );
+        sleep $factor;
+    }
 }
 
 {
@@ -886,10 +886,10 @@ while (time < $s) {
         {
             'x'      => 0,
             'y'      => $F->{'Y_CLIP'},
-            'width'  => $XX,
-            'height' => $h,
+            'width'  => $XX/2,
+            'height' => $h/2,
             'file'   => 'images/RWBY_beuowolf.jpg',
-            'center' => 1,
+            'center' => 3,
             'convertalpha' => 1
         }
     );
@@ -897,30 +897,31 @@ while (time < $s) {
         {
             'x'      => 0,
             'y'      => $F->{'Y_CLIP'},
-            'width'  => $XX,
-            'height' => $h,
+            'width'  => $XX/2,
+            'height' => $h/2,
             'file'   => 'images/RWBY_Alternate_Logo.png',
-            'center' => 1
+            'center' => 3
         }
     );
     $F->blit_write($image1);
     $F->unmask_mode();
     $F->blit_write($image2);
     sleep $factor;
-
-    print_it($F,'Simulating UNMASK Mode with the much quicker "blit_transform" and "merge"');
-    $F->blit_write($image2);
-    $F->blit_write(
-        $F->blit_transform(
-            {
-                'blit_data' => $image1,
-                'merge'     => {
-                    'dest_blit_data'=> $F->blit_read($image1)
+    if ($F->{'BITS'} > 16) {
+        print_it($F,'Simulating UNMASK Mode with the much quicker "blit_transform" and "merge"');
+        $F->blit_write($image2);
+        $F->blit_write(
+            $F->blit_transform(
+                {
+                    'blit_data' => $image1,
+                    'merge'     => {
+                        'dest_blit_data'=> $F->blit_read($image1)
+                    }
                 }
-            }
-        )
-    );
-    sleep $factor;
+            )
+        );
+        sleep $factor;
+    }
 }
 
 $F->clip_reset();
